<img src="https://gitlab.com/irides-dev/irides/raw/main/images/irides-tile-logo.1500px.png" alt="irides-logo" height="150"> 


# Reference Implementations for LTI Filters

[![pipeline status](https://gitlab.com/irides-dev/irides/badges/main/pipeline.svg)](https://gitlab.com/irides-dev/irides/pipelines)
[![coverage report](https://gitlab.com/irides-dev/irides/badges/main/coverage.svg)](https://gitlab.com/irides-dev/irides/commits/main)
[![license](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://gitlab.com/irides-dev/irides/blob/main/LICENSE)
[![Code style](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![python versions](https://img.shields.io/badge/py-%3E%3D3.7-blue)](https://pypi.python.org/pypi/irides)
[![numpy versions](https://img.shields.io/badge/numpy-%3E%3D1.23-blue)](https://www.numpy.org/)
[![pypi version](https://img.shields.io/pypi/v/irides.svg)](https://pypi.python.org/pypi/irides)
[![Conda Version](https://img.shields.io/conda/vn/conda-forge/irides.svg)](https://anaconda.org/conda-forge/irides)


## Overview


## Package Installation

The two package hosts for `irides` are [PyPi]() and [Conda-Forge](). The packages are identical and the only difference is the means of delivery. From PyPi, use `pip`,

```bash
$ pip install irides
```

and from Conda-Forge use `conda`:

```bash
$ conda install -c conda-forge irides
```

Once installed, the package is importable to Python:

```python
>>> import irides
```

## Package Dependency

The only dependencies `irides` has at this time is on [python >= 3.7](https://www.python.org/) and [numpy >= 1.23](https://www.numpy.org/). 


## Buell Lane Press

[Buell Lane Press](https://buell-lane-press.co) is the package sponsor. 

